@@ -3,7 +3,11 @@ package isolation
 import (
 	"encoding/json"
 	"fmt"
+	"os"
 	"os/exec"
+	"path/filepath"
+
+	virt_chroot "kubevirt.io/kubevirt/pkg/virt-handler/virt-chroot"
 
 	containerdisk "kubevirt.io/kubevirt/pkg/container-disk"
 )
@@ -14,8 +18,8 @@ const (
 
 func GetImageInfo(imagePath string, context IsolationResult) (*containerdisk.DiskInfo, error) {
 	// #nosec g204 no risk to use MountNamespace()  argument as it returns a fixed string of "/proc/<pid>/ns/mnt"
-	out, err := exec.Command(
-		"/usr/bin/virt-chroot", "--user", "qemu", "--memory", "1200", "--cpu", "10", "--mount", context.MountNamespace(), "exec", "--",
+	out, err := virt_chroot.ExecChroot(
+		"--user", "qemu", "--memory", "1200", "--cpu", "10", "--mount", context.MountNamespace(), "exec", "--",
 		QEMUIMGPath, "info", imagePath, "--output", "json",
 	).Output()
 	if err != nil {
@@ -34,3 +38,12 @@ func GetImageInfo(imagePath string, context IsolationResult) (*containerdisk.Dis
 	}
 	return info, err
 }
+
+func GetFileSize(imagePath string, context IsolationResult) (int64, error) {
+	path := filepath.Join(context.MountRoot(), imagePath)
+	info, err := os.Stat(path)
+	if err != nil {
+		return -1, err
+	}
+	return info.Size(), nil
+}
